@@ -273,7 +273,7 @@ Ciao!");
 			                           "your ideas and thoughts.\n\n" +
 			                           "You can create new notes to hold your ideas by " +
 			                           "selecting the \"Create New Note\" item from the " +
-			                           "Tomboy Notes menu in your GNOME Panel. " +
+			                           "Tomboy Notes menu. " +
 			                           "Your note will be saved automatically.\n\n" +
 			                           "Then organize the notes you create by linking " +
 			                           "related notes and ideas together!\n\n" +
