@@ -345,6 +345,7 @@ namespace Tomboy
 				"\tDave Foster",
 				"\tDavid Trowbridge",
 				"\tDoug Johnston",
+				"\tDavid Bannon",
 				"\tEveraldo Canuto",
 				"\tFrederic Crozat",
 				"\tGabriel Burt",
@@ -387,6 +388,7 @@ namespace Tomboy
 				"\tPaul Cutler",
 				"\tPavol Klačanský",
 				"\tPrzemysław Grzegorczyk",
+				"\tPhilip Withnall",
 				"\tRobert Buchholz",
 				"\tRobert Nordan",
 				"\tRobin Sonefors",
@@ -425,7 +427,7 @@ namespace Tomboy
 			about.Logo = GuiUtils.GetIcon ("tomboy", 48);
 			about.Copyright =
 			        Catalog.GetString ("Copyright \xa9 2004-2007 Alex Graveley\n" +
-				                   "Copyright \xa9 2004-2016 Others\n");
+				                   "Copyright \xa9 2004-2017 Others\n");
 			about.Comments = Catalog.GetString ("A simple and easy to use desktop " +
 			                                    "note-taking application.");
 			about.WindowPosition = Gtk.WindowPosition.Center;
@@ -578,7 +580,7 @@ namespace Tomboy
 			                "application.\n" +
 			                "Copyright \xa9 2004-2007 Alex Graveley\n" +
 							"<alex@beatniksoftware.com>\n\n" +		
-							"Copyright \xa9 2004-2016 Others\n"
+							"Copyright \xa9 2004-2017 Others\n"
 							);
 
 			Console.Write (about);
