@@ -581,11 +581,6 @@ namespace Tomboy
 
 			if (is_default) {
 				DefaultResponse = response;
-				button.AddAccelerator ("activate",
-				                       accel_group,
-				                       (uint) Gdk.Key.Escape,
-				                       0,
-				                       Gtk.AccelFlags.Visible);
 			}
 		}
 		
